@@ -291,7 +291,7 @@ impl<'r> EvalEnv<'r> {
                 let data = &p.data[off..];
                 oldrow.load(&self.db, data);
             } else {
-                panic!()
+                unreachable!()
             }
             t.remove(&self.db, &oldrow);
         }
