@@ -20,46 +20,14 @@
 //!
 //! It is also possible to access the table data directly, see email_loop in example (b).   
 //!
-//!# Examples
-//! (a) Simple single-threaded web server using SimpleFileStorage as underlying storage.
-//! ```
-//! use rustdb::{standard_builtins, AccessPagedData, Database, SharedPagedData, SimpleFileStorage, WebTransaction, INITSQL, BuiltinMap};
-//! use std::net::TcpListener;
-//! use std::sync::Arc;
-//!
-//! let sfs = Box::new(SimpleFileStorage::new( "..\\test.rustdb" ));
-//! let spd = Arc::new(SharedPagedData::new(sfs));
-//! let apd = AccessPagedData::new_writer(spd);
-//! let mut bmap = BuiltinMap::default();
-//! standard_builtins( &mut bmap );
-//! let bmap = Arc::new(bmap);
-//! let db = Database::new(apd, INITSQL, bmap);
-//!
-//! let listener = TcpListener::bind("127.0.0.1:3000").unwrap();
-//! for tcps in listener.incoming() {
-//!     if let Ok(mut tcps) = tcps {
-//!         if let Ok(mut tr) = WebTransaction::new(&tcps) {
-//!             // tr.trace();
-//!             let sql = "EXEC web.Main()";
-//!             // Execute SQL. http response, SQL output, (status,headers,content) is accumulated in wq.
-//!             db.run_timed(&sql, &mut tr);
-//!             // Write the http response to the TCP stream.
-//!             let _err = tr.write(&mut tcps);
-//!             // Save database changes to disk.
-//!             db.save();
-//!         }
-//!     }
-//! }
-//!```
-//!
-//! (b) [See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for more advanced example -
-//! an Axum-based webserver using [AtomicFile], the ARGON hash function, read-only queries and query logging.
+//!# Example
+//! [See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for an example progran -
+//! an Axum-based webserver.
 //!
 //!# Features
 //!
 //! This crate supports the following cargo features:
 //! - `gentrans` : enables gentrans module.
-//! - `webtrans` : enables webtrans module.
 //! - `builtin` : Allows extra SQL builtin functions to be defined.
 //! - `max` : maximal interface, including internal modules.
 //! - `verify` : Allows database structure to be verified using builtin function VERIFYDB.
@@ -90,10 +58,6 @@
 //!
 //!# ToDo Lists
 //!
-//! Consider compiling R-SQL functions to Rust, effectively "automatic builtin" functions.
-//!
-//! Unify GenTransaction and WebTransaction. File upload only partially works with WebTransaction currently.
-//!
 //! Implement email in example program. Replication of log files. Server status.
 //!
 //! Sort out error handling for PARSEINT etc.
@@ -112,9 +76,6 @@ pub use crate::{
 #[cfg(feature = "gentrans")]
 pub use crate::gentrans::{GenTransaction, Part};
 
-#[cfg(feature = "webtrans")]
-pub use crate::webtrans::WebTransaction;
-
 #[cfg(feature = "builtin")]
 pub use crate::{
     builtin::check_types,
@@ -171,10 +132,7 @@ mod util;
 /// [GenTransaction] ( implementation of [Transaction] ).
 pub mod gentrans;
 
-#[cfg(feature = "webtrans")]
-/// [WebTransaction] ( alternative implementation of [Transaction] with http support ).
-pub mod webtrans;
-
+#[cfg(feature = "init")]
 /// Initial SQL.
 ///
 /// Note : the [init::INITSQL] string can be generated using the "Script entire database" link in the runtime main menu,
