@@ -179,7 +179,7 @@ impl SharedPagedData {
     }
 
     /// Calculate the maxiumum size of a logical page. This value is stored in the Database struct.
-    pub(crate) fn page_size_max(&self) -> usize {
+    pub fn page_size_max(&self) -> usize {
         let ep_max = (self.sp_size - 2) / 8;
         (self.ep_size - 16) * ep_max + (self.sp_size - 2)
     }
@@ -189,7 +189,8 @@ impl SharedPagedData {
 pub struct AccessPagedData {
     writer: bool,
     time: u64,
-    pub(crate) spd: Arc<SharedPagedData>,
+    ///
+    pub spd: Arc<SharedPagedData>,
 }
 
 impl AccessPagedData {
@@ -213,7 +214,7 @@ impl AccessPagedData {
     }
 
     /// Get the Data for the specified page.
-    pub(crate) fn get_page(&self, lpnum: u64) -> Data {
+    pub fn get_page(&self, lpnum: u64) -> Data {
         // Get PageInfoPtr for the specified page.
         let pinfo = self.spd.stash.write().unwrap().get(lpnum);
 
@@ -225,7 +226,7 @@ impl AccessPagedData {
     }
 
     /// Set the data of the specified page.
-    pub(crate) fn set_page(&self, lpnum: u64, data: Data) {
+    pub fn set_page(&self, lpnum: u64, data: Data) {
         debug_assert!(self.writer);
 
         // First update the stash ( ensures any readers will not attempt to read the file ).
@@ -236,31 +237,31 @@ impl AccessPagedData {
     }
 
     /// Is the underlying file new (so needs to be initialised ).
-    pub(crate) fn is_new(&self) -> bool {
+    pub fn is_new(&self) -> bool {
         self.writer && self.spd.file.read().unwrap().is_new()
     }
 
     /// Check whether compressing a page is worthwhile.
-    pub(crate) fn compress(&self, size: usize, saving: usize) -> bool {
+    pub fn compress(&self, size: usize, saving: usize) -> bool {
         debug_assert!(self.writer);
         CompactFile::compress(self.spd.sp_size, self.spd.ep_size, size, saving)
     }
 
     /// Allocate a logical page.
-    pub(crate) fn alloc_page(&self) -> u64 {
+    pub fn alloc_page(&self) -> u64 {
         debug_assert!(self.writer);
         self.spd.file.write().unwrap().alloc_page()
     }
 
     /// Free a logical page.
-    pub(crate) fn free_page(&self, lpnum: u64) {
+    pub fn free_page(&self, lpnum: u64) {
         debug_assert!(self.writer);
         self.spd.stash.write().unwrap().set(lpnum, nd());
         self.spd.file.write().unwrap().free_page(lpnum);
     }
 
     /// Commit changes to underlying file ( or rollback logical page allocations ).
-    pub(crate) fn save(&self, op: SaveOp) -> usize {
+    pub fn save(&self, op: SaveOp) -> usize {
         debug_assert!(self.writer);
         match op {
             SaveOp::Save => {
