@@ -18,7 +18,7 @@ pub struct SortedFile {
     /// The root page.
     pub root_page: u64,
     /// Status
-    pub ok: Cell<bool>,
+    ok: Cell<bool>,
 }
 
 impl SortedFile {
