@@ -348,12 +348,7 @@ pub struct WriteAccess<'d, 'i> {
 impl<'d, 'i> WriteAccess<'d, 'i> {
     /// Save int to byte data.
     pub fn set_int(&mut self, colnum: usize, val: i64) {
-        util::set(
-            self.data,
-            self.info.off[colnum],
-            val as u64,
-            self.info.siz(colnum),
-        );
+        util::iset(self.data, self.info.off[colnum], val, self.info.siz(colnum));
     }
 
     /// Extract int from byte data for column number colnum.
@@ -663,15 +658,15 @@ impl Record for IndexRow {
 }
 
 /// Key for searching index.
-pub struct IndexKey {
-    ///
-    pub tinfo: Rc<ColInfo>,
-    ///
-    pub cols: Rc<Vec<usize>>,
-    ///
-    pub key: Vec<Value>,
-    ///
-    pub def: Ordering,
+struct IndexKey {
+    /// Information about the indexed table.
+    tinfo: Rc<ColInfo>,
+    /// List of indexed columns.
+    cols: Rc<Vec<usize>>,
+    /// Key values.
+    key: Vec<Value>,
+    /// Ordering used if keys compare equal.
+    def: Ordering,
 }
 
 impl IndexKey {
@@ -789,7 +784,7 @@ fn get_known_cols(we: &Expr, kc: &mut SmallSet) {
     }
 }
 
-/// Counts the number of index columns that are known.
+/// Count the number of index columns that are known.
 fn covered(clist: &[usize], kc: &SmallSet) -> usize {
     let mut result = 0;
     for &c in clist {
