@@ -49,6 +49,8 @@ pub enum WebErr {
     Eof,
     ///
     NewlineExpected,
+    ///
+    SemiColonExpected,
 }
 
 fn from_utf8(bytes: Vec<u8>) -> Result<String, WebErr> {
@@ -205,7 +207,6 @@ impl Transaction for WebTransaction {
                     0 => &p.name,
                     1 => &p.content_type,
                     2 => &p.file_name,
-                    3 => &p.text,
                     _ => panic!(),
                 }
             }
@@ -260,7 +261,8 @@ pub struct HttpRequestParser<'a> {
     end_content: usize, // End of content.
     content_length: usize,
     content_type: String,
-    content_disposition: String,
+    cd_name: String,
+    cd_filename: String,
     eof: bool,
 }
 
@@ -281,7 +283,8 @@ impl<'a> HttpRequestParser<'a> {
             end_content: usize::MAX,
             content_length: 0,
             content_type: String::new(),
-            content_disposition: String::new(),
+            cd_name: String::new(),
+            cd_filename: String::new(),
             eof: false,
         }
     }
@@ -439,14 +442,42 @@ impl<'a> HttpRequestParser<'a> {
                 if self.get_byte()? != 13 {
                     return Err(WebErr::NewlineExpected);
                 }
+            } else if name == "Content-Disposition" {
+                let fd = self.read_to(b';')?;
+                debug_assert!(fd == "form-data");
+                loop {
+                    self.skip_white_space()?;
+                    let name = self.read_to(b'=')?;
+                    if name == "" {
+                        if self.get_byte()? != 13 {
+                            return Err(WebErr::NewlineExpected);
+                        }
+                        break;
+                    }
+                    let val = {
+                        if self.get_byte()? == b'"' {
+                            let val = self.read_to(b'"')?;
+                            if self.get_byte()? != b';' {
+                                self.index -= 1;
+                            }
+                            val
+                        } else {
+                            self.index -= 1;
+                            self.read_to(b';')?
+                        }
+                    };
+                    if name == "name" {
+                        self.cd_name = val;
+                    } else if name == "filename" {
+                        self.cd_filename = val;
+                    }
+                }
             } else {
                 let value = self.read_to(13)?;
                 if name == "Content-Type" {
                     self.content_type = value.clone();
                 } else if name == "Content-Length" {
                     self.content_length = value.parse::<usize>().unwrap();
-                } else if name == "Content-Disposition" {
-                    self.content_disposition = value.clone();
                 } else {
                     // println!("header name={} value={}", name, value );
                 }
@@ -503,7 +534,6 @@ impl<'a> HttpRequestParser<'a> {
         let mut ok = true;
         while ok {
             let _headers = self.read_headers()?;
-            println!("headers={:?}", _headers);
             let mut body = Vec::new();
             ok = false;
             while !self.eof {
@@ -511,16 +541,12 @@ impl<'a> HttpRequestParser<'a> {
                 body.push(b);
                 // Check to see if we matched separator
                 if ends_with(&body, &seperator) {
-                    println!("Got seperator");
-                    println!("Content disposition={}", self.content_disposition);
                     let part = Part {
-                        name: Rc::new("file".to_string()),
+                        name: Rc::new(self.cd_name.clone()),
                         content_type: self.content_type.clone(),
-                        file_name: Rc::new("todo".to_string()),
-                        text: Rc::new("ToDo".to_string()),
+                        file_name: Rc::new(self.cd_filename.clone()),
                         data: Arc::new(body),
                     };
-                    println!("content type={}", part.content_type);
                     result.push(part);
                     let b = self.get_byte()?;
                     ok = b == 13;
@@ -552,8 +578,6 @@ pub struct Part {
     ///
     pub name: Rc<String>,
     ///
-    pub text: Rc<String>,
-    ///
     pub file_name: Rc<String>,
     ///
     pub content_type: String,
